# Live Demos
import DocsCard from '@components/global/DocsCard';
import DocsCards from '@components/global/DocsCards';

Build AI-powered knowledge bases & visual search applications effortlessly with seekdb. Dive into live demos to experience real-time semantic query and multi-modal search in action.

<DocsCards>
  <DocsCard header="AI Knowledge Base with Vector Search" href="https://en.oceanbase.com/demo/chatbot" icon="/icons/native-cordova-bot.png">
    <p>seekdb integrates vector search and RAG to build a lightweight AI knowledge base for official docs, offering instant Q&A out of the box.</p>
  </DocsCard>

<DocsCard header="Image Search with Vector Search" href="https://en.oceanbase.com/demo/image-search" icon="/icons/component-searchbar-icon.png">
  <p>seekdb integrates vector search into SQL, using deep learning to extract image features and build simple image search apps with SQL+AI.</p>
</DocsCard>
</DocsCards>
